@@ -11,7 +11,7 @@ from edx_rbac.mixins import PermissionRequiredMixin
 from edx_rest_framework_extensions.auth.jwt.authentication import JwtAuthentication
 from edx_rest_framework_extensions.paginators import DefaultPagination
 from rest_framework import filters, viewsets
-from rest_framework.decorators import list_route
+from rest_framework.decorators import action
 from rest_framework.response import Response
 
 from django.db.models import Count, Max, OuterRef, Q, Subquery, Value
@@ -23,6 +23,7 @@ from enterprise_data.api.v0 import serializers
 from enterprise_data.filters import (
     CONSENT_TRUE_OR_NOENROLL_Q,
     AuditEnrollmentsFilterBackend,
+    AuditUsersEnrollmentFilterBackend,
     ConsentGrantedFilterBackend,
 )
 from enterprise_data.models import EnterpriseEnrollment, EnterpriseUser
@@ -55,7 +56,7 @@ class EnterpriseViewSet(PermissionRequiredMixin, viewsets.ViewSet):
         """
         if 'no_page' in self.request.query_params:
             return None
-        return super(EnterpriseViewSet, self).paginate_queryset(queryset)
+        return super(EnterpriseViewSet, self).paginate_queryset(queryset)  # pylint: disable=no-member
 
 
 class EnterpriseEnrollmentsViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
@@ -125,7 +126,7 @@ class EnterpriseEnrollmentsViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
         """
         return queryset.filter(
             has_passed=False,
-            course_end__gte=date.today(),
+            course_end__gte=timezone.now(),
         )
 
     def filter_distinct_learners(self, queryset):
@@ -162,7 +163,7 @@ class EnterpriseEnrollmentsViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
         """
         Filters only those learners who completed a course in last week.
         """
-        date_today = date.today()
+        date_today = timezone.now()
         date_week_before = date_today - timedelta(weeks=1)
         return queryset.filter(
             has_passed=True,
@@ -184,7 +185,7 @@ class EnterpriseEnrollmentsViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
         created_max = queryset.aggregate(Max('created'))
         return created_max['created__max']
 
-    @list_route()
+    @action(detail=False)
     def overview(self, request, **kwargs):  # pylint: disable=unused-argument
         """
         Returns the following data:
@@ -222,7 +223,7 @@ class EnterpriseUsersViewSet(EnterpriseViewSet, viewsets.ModelViewSet):
     """
     queryset = EnterpriseUser.objects.all()
     serializer_class = serializers.EnterpriseUserSerializer
-    filter_backends = (filters.OrderingFilter,)
+    filter_backends = (filters.OrderingFilter, AuditUsersEnrollmentFilterBackend,)
     ordering_fields = '__all__'
     ordering = ('user_email',)
 
